# bunny-sdk

[![PyPI - Version](https://img.shields.io/pypi/v/bunny-sdk?color=blue)](https://pypi.org/project/bunny-sdk/)

<!-- poetry folder name uses underscores https://github.com/python-poetry/poetry/issues/8942#issuecomment-1925761531 -->
<!-- poetry pypi authentication https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04 -->

## Installation

```shell
pip install bunny-sdk
```

## Documentation

Please read the [docs](https://bunny-launcher.net/bunny-sdk/languages/python/) for usage and examples.
